@@ -28,21 +28,25 @@
 #define __MLVIEW_XSLT_UTILS_H__
 
 #include <glib-object.h>
+#include "mlview-xml-document.h"
+#include "mlview-editor.h"
 
-G_BEGIN_DECLS
-
+namespace mlview
+{
 /* xslt namespace uri */
 #define XSLT_NAMESPACE_URI "http://www.w3.org/1999/XSL/Transform"
 
 /* select xslt form response */
 #define MLVIEW_XSLT_UTILS_RESPONSE_BROWSE 3
 
-gboolean mlview_xslt_utils_is_xslt_doc(MlViewXMLDocument* mlv_xml_doc) ;
-MlViewXMLDocument *mlview_xslt_utils_select_xsl_doc  (MlViewEditor *a_this);
-MlViewXMLDocument *mlview_xslt_utils_transform_document (MlViewXMLDocument *src_doc, 
-							 MlViewXMLDocument *xsl_doc);
+gboolean xslt_utils_is_xslt_doc (MlViewXMLDocument* a_mlv_xml_doc) ;
 
-G_END_DECLS
+MlViewXMLDocument *_xslt_utils_select_xsl_doc  (Editor *a_this);
+
+MlViewXMLDocument *xslt_utils_transform_document (MlViewXMLDocument *src_doc,
+        MlViewXMLDocument *xsl_doc);
+
+}//namespace mlview
 
 #endif /* __mlview_xslt_utils_XSLT_UTILS_H__ */
 
